pub struct Codex { /* private fields */ }Expand description
The high-level interface to the Codex system. It operates as a queue pair where you send submissions and receive events.
Implementations
Sourceimpl Codex
impl Codex
Sourcepub async fn spawn(
config: Config,
auth: Option<CodexAuth>,
) -> CodexResult<CodexSpawnOk>
pub async fn spawn( config: Config, auth: Option<CodexAuth>, ) -> CodexResult<CodexSpawnOk>
Spawn a new Codex and initialize the session.
Sourcepub async fn submit(&self, op: Op) -> CodexResult<String>
pub async fn submit(&self, op: Op) -> CodexResult<String>
Submit the op wrapped in a Submission with a unique ID.
Sourcepub async fn submit_with_id(&self, sub: Submission) -> CodexResult<()>
pub async fn submit_with_id(&self, sub: Submission) -> CodexResult<()>
Use sparingly: prefer submit() so Codex is responsible for generating
unique IDs for each submission.
pub async fn next_event(&self) -> CodexResult<Event>