pub struct ConfigToml {Show 30 fields
pub model: Option<String>,
pub model_provider: Option<String>,
pub model_context_window: Option<u64>,
pub model_max_output_tokens: Option<u64>,
pub approval_policy: Option<AskForApproval>,
pub shell_environment_policy: ShellEnvironmentPolicyToml,
pub sandbox_mode: Option<SandboxMode>,
pub sandbox_workspace_write: Option<SandboxWorkspaceWrite>,
pub disable_response_storage: Option<bool>,
pub notify: Option<Vec<String>>,
pub instructions: Option<String>,
pub mcp_servers: HashMap<String, McpServerConfig>,
pub model_providers: HashMap<String, ModelProviderInfo>,
pub project_doc_max_bytes: Option<usize>,
pub profile: Option<String>,
pub profiles: HashMap<String, ConfigProfile>,
pub history: Option<History>,
pub file_opener: Option<UriBasedFileOpener>,
pub tui: Option<Tui>,
pub hide_agent_reasoning: Option<bool>,
pub show_raw_agent_reasoning: Option<bool>,
pub model_reasoning_effort: Option<ReasoningEffort>,
pub model_reasoning_summary: Option<ReasoningSummary>,
pub model_supports_reasoning_summaries: Option<bool>,
pub chatgpt_base_url: Option<String>,
pub experimental_resume: Option<PathBuf>,
pub experimental_instructions_file: Option<PathBuf>,
pub responses_originator_header_internal_override: Option<String>,
pub projects: Option<HashMap<String, ProjectConfig>>,
pub preferred_auth_method: Option<AuthMode>,
}Expand description
Base config deserialized from ~/.agcodex/config.toml.
Fields
model: Option<String>Optional override of model selection.
model_provider: Option<String>Provider to use from the model_providers map.
model_context_window: Option<u64>Size of the context window for the model, in tokens.
model_max_output_tokens: Option<u64>Maximum number of output tokens.
approval_policy: Option<AskForApproval>Default approval policy for executing commands.
shell_environment_policy: ShellEnvironmentPolicyTomlsandbox_mode: Option<SandboxMode>Sandbox mode to use.
sandbox_workspace_write: Option<SandboxWorkspaceWrite>Sandbox configuration to apply if sandbox is WorkspaceWrite.
disable_response_storage: Option<bool>Disable server-side response storage (sends the full conversation context with every request). Currently necessary for OpenAI customers who have opted into Zero Data Retention (ZDR).
notify: Option<Vec<String>>Optional external command to spawn for end-user notifications.
instructions: Option<String>System instructions.
mcp_servers: HashMap<String, McpServerConfig>Definition for MCP servers that Codex can reach out to for tool calls.
model_providers: HashMap<String, ModelProviderInfo>User-defined provider entries that extend/override the built-in list.
project_doc_max_bytes: Option<usize>Maximum number of bytes to include from an AGENTS.md project doc file.
profile: Option<String>Profile to use from the profiles map.
profiles: HashMap<String, ConfigProfile>Named profiles to facilitate switching between different configurations.
history: Option<History>Settings that govern if and what will be written to ~/.agcodex/history.jsonl.
file_opener: Option<UriBasedFileOpener>Optional URI-based file opener. If set, citations to files in the model output will be hyperlinked using the specified URI scheme.
tui: Option<Tui>Collection of settings that are specific to the TUI.
hide_agent_reasoning: Option<bool>When set to true, AgentReasoning events will be hidden from the
UI/output. Defaults to false.
show_raw_agent_reasoning: Option<bool>When set to true, AgentReasoningRawContentEvent events will be shown in the UI/output.
Defaults to false.
model_reasoning_effort: Option<ReasoningEffort>model_reasoning_summary: Option<ReasoningSummary>model_supports_reasoning_summaries: Option<bool>Override to force-enable reasoning summaries for the configured model.
chatgpt_base_url: Option<String>Base URL for requests to ChatGPT (as opposed to the OpenAI API).
experimental_resume: Option<PathBuf>Experimental rollout resume path (absolute path to .jsonl; undocumented).
experimental_instructions_file: Option<PathBuf>Experimental path to a file whose contents replace the built-in BASE_INSTRUCTIONS.
responses_originator_header_internal_override: Option<String>The value for the originator header included with Responses API requests.
projects: Option<HashMap<String, ProjectConfig>>preferred_auth_method: Option<AuthMode>If set to true, the API key will be signed with the originator header.
Implementations
Sourceimpl ConfigToml
impl ConfigToml
pub fn is_cwd_trusted(&self, resolved_cwd: &Path) -> bool
pub fn get_config_profile( &self, override_profile: Option<String>, ) -> Result<ConfigProfile, Error>