pub struct CodexConversation { /* private fields */ }Implementations
Sourceimpl CodexConversation
Conduit for the bidirectional stream of messages that compose a conversation
in Codex.
impl CodexConversation
Conduit for the bidirectional stream of messages that compose a conversation in Codex.
pub async fn submit(&self, op: Op) -> CodexResult<String>
Sourcepub async fn submit_with_id(&self, sub: Submission) -> CodexResult<()>
pub async fn submit_with_id(&self, sub: Submission) -> CodexResult<()>
Use sparingly: this is intended to be removed soon.
pub async fn next_event(&self) -> CodexResult<Event>