pub fn simple_error<T>(
result: T,
tool: &'static str,
operation: String,
error_message: String,
) -> ComprehensiveToolOutput<T>Expand description
Create a simple error output for tools that encounter failures
pub fn simple_error<T>(
result: T,
tool: &'static str,
operation: String,
error_message: String,
) -> ComprehensiveToolOutput<T>Create a simple error output for tools that encounter failures